@@ -45,7 +45,7 @@ sub run
     }
     elsif( defined(my $handler = $s->modes( $mode )) )
     {
-      return $handler->( @_ );
+      return $handler->( $s, $context );
     }# end if()
   }# end if()
   
@@ -195,10 +195,11 @@ sub compose_upload_file_name
 {
   my ($s, $context, $Upload) = @_;
   
-  my ($filename) = $Upload->{upload}->upload_filename =~ m/.*[\\\/]([^\/\\]+)$/;
+#  my $filename = $Upload;
+  my ($filename) = $Upload->{upload}->{upload_filename} =~ m/.*[\\\/]([^\/\\]+)$/;
   if( ! $filename )
   {
-    $filename = $Upload->{upload}->upload_filename;
+    $filename = $Upload->{upload}->{upload_filename};
   }# end if()
   
   return $filename;
@@ -240,20 +241,18 @@ sub upload_start
   $ofh->close;
   
   # Store some information for later:
-  $ENV{filename} = $target_file;
-  $ENV{download_file} = $filename;
+  $ENV{filename} ||= $target_file;
+  $ENV{download_file} ||= $filename;
   
   # Depending on the 'mode' parameter, we do different things:
   local $_ = $s->_args('mode');
   if( /^create$/ )
   {
-    $s->before_create($context, $Upload)
-      or return;
+    $s->before_create($context, $Upload);
   }
   elsif( /^edit$/ )
   {
-    $s->before_update($context, $Upload)
-      or return;
+    $s->before_update($context, $Upload);
   }
   else
   {
@@ -299,12 +298,14 @@ sub upload_end
   $Upload->{$_} = $info->{$_} foreach keys(%$info);
   
   # Depending on the 'mode' parameter, we do different things:
-  local $_ = $context->request->Form->{mode};
-  if( /^create$/ )
+#  local $_ = $context->request->Form->{mode};
+  my $form = $context->request->Form;
+  $form = $context->request->Form;
+  if( $form->{mode} =~ /^create$/ )
   {
     $s->after_create($context, $Upload);
   }
-  elsif( /^edit$/ )
+  elsif(  $form->{mode} =~ /^edit$/ )
   {
     $s->after_update($context, $Upload);
   }
